==> haskell-regex-base-0.94.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-base
version:              0.94.0.1
visibility:           public
id:                   regex-base-0.94.0.1-61S2JIUUNzk1MaMYHGGdFS
key:                  regex-base-0.94.0.1-61S2JIUUNzk1MaMYHGGdFS
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Common "Text.Regex.*" API for Regex matching
description:
    This package does not provide the ability to do regular expression matching.
    Instead, it provides the type classes that constitute the abstract API
    that is implemented by @regex-*@ backends such as:

    * <https://hackage.haskell.org/package/regex-posix regex-posix>

    * <https://hackage.haskell.org/package/regex-parsec regex-parsec>

    * <https://hackage.haskell.org/package/regex-dfa regex-dfa>

    * <https://hackage.haskell.org/package/regex-tdfa regex-tdfa>

    * <https://hackage.haskell.org/package/regex-pcre regex-pcre>

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  409c7c1121289a91ee2f73c27654ca25
exposed:              True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike

hidden-modules:       Paths_regex_base
import-dirs:          /usr/lib/ghc-8.10.4/site-local/regex-base-0.94.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/regex-base-0.94.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/regex-base-0.94.0.1
hs-libraries:         HSregex-base-0.94.0.1-61S2JIUUNzk1MaMYHGGdFS
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    mtl-2.2.2 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html:         /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-base-0.94.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-base
version:              0.94.0.1
visibility:           public
id:                   regex-base-0.94.0.1-BhcrfAa0EaQLabAeJ8QV4e
key:                  regex-base-0.94.0.1-BhcrfAa0EaQLabAeJ8QV4e
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Common "Text.Regex.*" API for Regex matching
description:
    This package does not provide the ability to do regular expression matching.
    Instead, it provides the type classes that constitute the abstract API
    that is implemented by @regex-*@ backends such as:

    * <https://hackage.haskell.org/package/regex-posix regex-posix>

    * <https://hackage.haskell.org/package/regex-parsec regex-parsec>

    * <https://hackage.haskell.org/package/regex-dfa regex-dfa>

    * <https://hackage.haskell.org/package/regex-tdfa regex-tdfa>

    * <https://hackage.haskell.org/package/regex-pcre regex-pcre>

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  ee2fe2de2a06c5b5bfbe4c796ca9a1b3
exposed:              True
exposed-modules:
    Text.Regex.Base Text.Regex.Base.Context Text.Regex.Base.Impl
    Text.Regex.Base.RegexLike

hidden-modules:       Paths_regex_base
import-dirs:          /usr/lib/ghc-8.10.5/site-local/regex-base-0.94.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/regex-base-0.94.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/regex-base-0.94.0.1
hs-libraries:         HSregex-base-0.94.0.1-BhcrfAa0EaQLabAeJ8QV4e
depends:
    array-0.5.4.0 base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    mtl-2.2.2 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-regex-base/html/regex-base.haddock
haddock-html:         /usr/share/doc/haskell-regex-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
